@@ -325,6 +325,13 @@ export const globalSettings = {
               type: yup.boolean(),
               defaultValue: false,
             },
+            medicationAlreadyOrderedConfirmationTimeout: {
+              description:
+                'Ask confirmation from users if they try to order a medication that has been ordered within the timeout period',
+              type: yup.number().positive(),
+              defaultValue: 24,
+              unit: 'hours',
+            },
           },
         },
         useGlobalPdfFont: {
@@ -332,6 +339,16 @@ export const globalSettings = {
           type: yup.boolean(),
           defaultValue: false,
         },
+        deviceRegistrationQuota: {
+          description: 'Device registration quota settings',
+          properties: {
+            enabled: {
+              description: 'Enable device registration quota',
+              type: yup.boolean(),
+              defaultValue: true,
+            },
+          },
+        },
       },
     },
     customisations: {
